@@ -17,7 +17,7 @@
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-	$Id: address.c 7778 2005-06-05 21:12:02Z wsl $
+	$Id: address.c 7979 2005-06-28 13:25:59Z wsl $
 	$URL: https://infix.uvt.nl/its-id/trunk/sources/fair/src/address.c $
 
 ******************************************************************************/
@@ -81,7 +81,9 @@ int address_cmp_addr(const address_t *aa, const address_t *ba) {
 int address_cmp_prio(const address_t *aa, const address_t *ba) {
 	bool ab, bb;
 	u32 ar, br;
+#if 0
 	sa_family_t af, bf;
+#endif
 
 	ab = aa->disabled;
 	bb = ba->disabled;
@@ -111,6 +113,7 @@ int address_cmp_prio(const address_t *aa, const address_t *ba) {
 	if(ar > br)
 		return 1;
 
+#if 0
 	af = address_sa(aa)->sa_family;
 	bf = address_sa(ba)->sa_family;
 	if(af > bf)
@@ -122,6 +125,8 @@ int address_cmp_prio(const address_t *aa, const address_t *ba) {
 		return -1;
 	if(aa > ba)
 		return 1;
+#endif
+
 	return 0;
 }
 
